@@ -8,20 +8,22 @@ import operator
 import os
 import sys
 import time
+import torch
+from transformers import pipeline
+from loguru import logger
 
 sys.path.append('../..')
-from pycorrector.utils.text_utils import is_chinese_string, convert_to_unicode
-from pycorrector.utils.logger import logger
+from pycorrector.utils.text_utils import is_chinese_string
 from pycorrector.corrector import Corrector
-from pycorrector.transformers import pipeline
 from pycorrector import config
 from pycorrector.utils.tokenizer import split_text_by_maxlen
 
 pwd_path = os.path.abspath(os.path.dirname(__file__))
+device_id = 0 if torch.cuda.is_available() else -1
 
 
 class BertCorrector(Corrector):
-    def __init__(self, bert_model_dir=config.bert_model_dir):
+    def __init__(self, bert_model_dir=config.bert_model_dir, device=device_id):
         super(BertCorrector, self).__init__()
         self.name = 'bert_corrector'
         t1 = time.time()
@@ -29,7 +31,7 @@ class BertCorrector(Corrector):
             'fill-mask',
             model=bert_model_dir,
             tokenizer=bert_model_dir,
-            device=0,  # gpu device id
+            device=device,  # gpu device id
         )
         if self.model:
             self.mask = self.model.tokenizer.mask_token
@@ -44,8 +46,6 @@ class BertCorrector(Corrector):
         text_new = ''
         details = []
         self.check_corrector_initialized()
-        # 编码统一，utf-8 to unicode
-        text = convert_to_unicode(text)
         # 长句切分为短句
         blocks = split_text_by_maxlen(text, maxlen=128)
         for blk, start_idx in blocks:
