@@ -11,19 +11,13 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
 import os
 import sys
 from pathlib import Path
 
 from tqdm import tqdm
-
-sys.path.append('../..')
-from pycorrector.utils.logger import logger
+from loguru import logger
 
 
 def _fetch_from_remote(url, force_download=False, cached_dir='~/.paddle-ernie-cache'):
@@ -51,7 +45,26 @@ def _fetch_from_remote(url, force_download=False, cached_dir='~/.paddle-ernie-ca
                     f.flush()
             logger.debug('extacting... to %s' % tmpfile)
             with tarfile.open(tmpfile.as_posix())  as tf:
-                tf.extractall(path=cached_dir_model.as_posix())
+                def is_within_directory(directory, target):
+                    
+                    abs_directory = os.path.abspath(directory)
+                    abs_target = os.path.abspath(target)
+                
+                    prefix = os.path.commonprefix([abs_directory, abs_target])
+                    
+                    return prefix == abs_directory
+                
+                def safe_extract(tar, path=".", members=None, *, numeric_owner=False):
+                
+                    for member in tar.getmembers():
+                        member_path = os.path.join(path, member.name)
+                        if not is_within_directory(path, member_path):
+                            raise Exception("Attempted Path Traversal in Tar File")
+                
+                    tar.extractall(path, members, numeric_owner=numeric_owner) 
+                    
+                
+                safe_extract(tf, path=cached_dir_model.as_posix())
         os.remove(tmpfile.as_posix())
     logger.debug('%s cached in %s' % (url, cached_dir))
     return cached_dir_model
