@@ -12,20 +12,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import json
 from pathlib import Path
 
 import paddle.fluid as F
 import paddle.fluid.dygraph as D
 import paddle.fluid.layers as L
-
+from loguru import logger
 from .file_utils import _fetch_from_remote, add_docstring
-from ..utils.logger import logger
 
 
 def _build_linear(n_in, n_out, name, init, act=None):
