@@ -12,11 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import io
 import re
 from functools import partial
@@ -24,9 +19,8 @@ from pathlib import Path
 
 import numpy as np
 import six
-
+from loguru import logger
 from .file_utils import _fetch_from_remote
-from ..utils.logger import logger
 
 open = partial(io.open, encoding='utf8')
 
