@@ -5,10 +5,6 @@
 @Author :   Abtion
 @Email  :   abtion{at}outlook.com
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import argparse
 import sys
 
@@ -34,12 +30,15 @@ def main():
     i = nlp('少先队员英该为老人让座')
     print(i)
 
-    i = nlp('机器学习是人工智能领遇最能体现智能的一个分知')
+    i = nlp('机器学习是人工智能领遇最能体现智能的一个分知。')
     print(i)
 
-    i = nlp('机其学习是人工智能领遇最能体现智能的一个分知')
+    i = nlp('机其学习是人工智能领遇最能体现智能的一个分知。')
     print(i)
 
+    print(nlp('老是较书。'))
+    print(nlp('遇到一位很棒的奴生跟我聊天。'))
+
 
 if __name__ == "__main__":
     main()
