@@ -1,39 +1,17 @@
 # -*- coding: utf-8 -*-
-# Author: XuMing(xuming624@qq.com)
-# Brief: 汉字处理的工具:判断unicode是否是汉字，数字，英文，或者其他字符。以及全角符号转半角符号。
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+"""
+@author:XuMing(xuming624@qq.com)
+@description: 汉字处理的工具:判断unicode是否是汉字，数字，英文，或者其他字符。以及全角符号转半角符号。
+"""
 
 import re
 
 import pypinyin
-import six
 from pypinyin import pinyin
 
 from pycorrector.utils.langconv import Converter
 
 
-def convert_to_unicode(text):
-    """Converts `text` to Unicode (if it's not already), assuming utf-8 input."""
-    if six.PY3:
-        if isinstance(text, str):
-            return text
-        elif isinstance(text, bytes):
-            return text.decode("utf-8", "ignore")
-        else:
-            raise ValueError("Unsupported string type: %s" % (type(text)))
-    elif six.PY2:
-        if isinstance(text, str):
-            return text.decode("utf-8", "ignore")
-        elif isinstance(text, unicode):
-            return text
-        else:
-            raise ValueError("Unsupported string type: %s" % (type(text)))
-    else:
-        raise ValueError("Not running on Python2 or Python 3?")
-
-
 def is_chinese(uchar):
     """判断一个unicode是否是汉字"""
     return '\u4e00' <= uchar <= '\u9fa5'
@@ -59,6 +37,11 @@ def is_alphabet_string(string):
     return all(is_alphabet(c) for c in string)
 
 
+def is_alphabet_number_string(string):
+    """判断全是数字和英文字符"""
+    return all((is_alphabet(c) or is_number(c)) for c in string)
+
+
 def is_other(uchar):
     """判断是否非汉字，数字和英文字符"""
     return not (is_chinese(uchar) or is_number(uchar) or is_alphabet(uchar))
@@ -175,3 +158,11 @@ if __name__ == "__main__":
     print(traditional_sentence, simplified_sentence)
     print(is_alphabet_string('Teacher'))
     print(is_alphabet_string('Teacher '))
+
+    print('*' * 12)
+    print(is_alphabet_number_string('nihao123'))
+    print(is_alphabet_number_string('ni*hao12'))
+    print(is_alphabet_number_string('12'))
+    print(is_alphabet_number_string('teacher'))
+    print(is_alphabet_number_string('oppo12'))
+    print(is_alphabet_number_string('oppo12 '))
